@@ -2,7 +2,7 @@
 /*  displist.c
  * 
  * 
- * $Id: displist.c,v 1.16 2004/01/10 01:22:06 rwenzlaff Exp $
+ * $Id: displist.c,v 1.23 2004/05/06 17:32:17 ton Exp $
  *
  * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
  *
@@ -55,6 +55,7 @@
 #include "DNA_lamp_types.h"
 #include "DNA_object_types.h"
 #include "DNA_mesh_types.h"
+#include "DNA_meshdata_types.h"
 #include "DNA_scene_types.h"
 #include "DNA_image_types.h"
 #include "DNA_material_types.h"
@@ -106,48 +107,52 @@ struct _FastLamp {
 static FastLamp *fastlamplist= NULL;
 static float fviewmat[4][4];
 
-DispListMesh *displistmesh_from_editmesh(ListBase *verts, ListBase *edges, ListBase *faces) {
+DispListMesh *displistmesh_from_editmesh(EditMesh *em) 
+{
 	DispListMesh *dlm= MEM_callocN(sizeof(*dlm),"dlm");
-	int i;
 	EditVert *eve, *evePrev;
 	EditEdge *eed;
 	EditVlak *evl;
+	MFace *mfNew;
+	int i;
 
 	dlm->flag= 0;
-	dlm->totvert= BLI_countlist(verts);
-	dlm->totface= BLI_countlist(edges)+BLI_countlist(faces);
+	dlm->totvert= BLI_countlist(&em->verts);
+	dlm->totface= BLI_countlist(&em->edges)+BLI_countlist(&em->faces);
 	dlm->mvert= MEM_callocN(sizeof(*dlm->mface)*dlm->totvert, "dlm->mvert");
 	dlm->mcol= NULL;
 	dlm->tface= NULL;
 	dlm->mface= MEM_mallocN(sizeof(*dlm->mface)*dlm->totface, "dlm->mface");
 
 	i=0;
-	for (eve= verts->first; eve; eve= eve->next, i++) {
+	for (eve= em->verts.first; eve; eve= eve->next, i++) {
 		MVert *mvNew= &dlm->mvert[i];
 		VECCOPY(mvNew->co, eve->co);
 		eve->prev= (void*) i;	/* hack to fetch indices */
 	}
 
-	i=0;
-	for (evl= faces->first; evl; evl= evl->next, i++) {
-		MFaceInt *mfNew= &dlm->mface[i];
-
-		mfNew->v1= (int) evl->v1->prev;
-		mfNew->v2= (int) evl->v2->prev;
-		mfNew->v3= (int) evl->v3->prev;
-		mfNew->v4= evl->v4?(int) evl->v4->prev:0;
-		mfNew->flag= evl->flag;
-		mfNew->mat_nr= evl->mat_nr;
-		mfNew->puno= 0;
-		mfNew->edcode= 0;
-
-		if (evl->v4 && !mfNew->v4) {
-			mfNew->v1^= mfNew->v3^= mfNew->v1^= mfNew->v3;
-			mfNew->v2^= mfNew->v4^= mfNew->v2^= mfNew->v4;
+	mfNew= dlm->mface;
+	for (evl= em->faces.first; evl; evl= evl->next) {
+		// we skip hidden faces
+		if(evl->v1->h || evl->v2->h || evl->v3->h || (evl->v4 && evl->v4->h)) dlm->totface--;
+		else {
+			mfNew->v1= (int) evl->v1->prev;
+			mfNew->v2= (int) evl->v2->prev;
+			mfNew->v3= (int) evl->v3->prev;
+			mfNew->v4= evl->v4?(int) evl->v4->prev:0;
+			mfNew->flag= evl->flag;
+			mfNew->mat_nr= evl->mat_nr;
+			mfNew->puno= 0;
+			mfNew->edcode= 0;
+	
+			if (evl->v4 && !mfNew->v4) {
+				mfNew->v1^= mfNew->v3^= mfNew->v1^= mfNew->v3;
+				mfNew->v2^= mfNew->v4^= mfNew->v2^= mfNew->v4;
+			}
+			mfNew++;
 		}
 	}
-	for (eed= edges->first; eed; eed= eed->next, i++) {
-		MFaceInt *mfNew= &dlm->mface[i];
+	for (eed= em->edges.first; eed; eed= eed->next, mfNew++) {
 
 		mfNew->v1= (int) eed->v1->prev;
 		mfNew->v2= (int) eed->v2->prev;
@@ -160,14 +165,15 @@ DispListMesh *displistmesh_from_editmesh(ListBase *verts, ListBase *edges, ListB
 	}
 
 		/* restore prev links */
-	for (evePrev=NULL, eve= verts->first; eve; evePrev=eve, eve= eve->next)
+	for (evePrev=NULL, eve= em->verts.first; eve; evePrev=eve, eve= eve->next)
 		eve->prev= evePrev;
 
 	displistmesh_calc_vert_normals(dlm);
 
 	return dlm;
 }
-DispListMesh *displistmesh_from_mesh(Mesh *me, float *extverts) {
+DispListMesh *displistmesh_from_mesh(Mesh *me, float *extverts) 
+{
 	DispListMesh *dlm= MEM_callocN(sizeof(*dlm),"dlm");
 	int i;
 	dlm->flag= 0;
@@ -185,7 +191,7 @@ DispListMesh *displistmesh_from_mesh(Mesh *me, float *extverts) {
 	}
 	for (i=0; i<dlm->totface; i++) {
 		MFace *mfOld= &((MFace*) me->mface)[i];
-		MFaceInt *mfNew= &dlm->mface[i];
+		MFace *mfNew= &dlm->mface[i];
 
 		mfNew->v1= mfOld->v1;
 		mfNew->v2= mfOld->v2;
@@ -200,7 +206,8 @@ DispListMesh *displistmesh_from_mesh(Mesh *me, float *extverts) {
 	return dlm;
 }
 
-void displistmesh_free(DispListMesh *dlm) {
+void displistmesh_free(DispListMesh *dlm) 
+{
 	// also check on mvert and mface, can be NULL after decimator (ton)
 	if( dlm->mvert) MEM_freeN(dlm->mvert);
 	if (dlm->mface) MEM_freeN(dlm->mface);
@@ -219,16 +226,17 @@ static DispListMesh *displistmesh_copy(DispListMesh *odlm) {
 	return ndlm;
 }
 
-void displistmesh_calc_vert_normals(DispListMesh *dlm) {
+void displistmesh_calc_vert_normals(DispListMesh *dlm) 
+{
 	MVert *mverts= dlm->mvert;
 	int nmverts= dlm->totvert;
-	MFaceInt *mfaces= dlm->mface;
+	MFace *mfaces= dlm->mface;
 	int nmfaces= dlm->totface;
 	float (*tnorms)[3]= MEM_callocN(nmverts*sizeof(*tnorms), "tnorms");
 	int i;
 	
 	for (i=0; i<nmfaces; i++) {
-		MFaceInt *mf= &mfaces[i];
+		MFace *mf= &mfaces[i];
 		float f_no[3];
 
 		if (!mf->v3)
@@ -258,11 +266,12 @@ void displistmesh_calc_vert_normals(DispListMesh *dlm) {
 	MEM_freeN(tnorms);
 }
 
-void displistmesh_to_mesh(DispListMesh *dlm, Mesh *me) {
+void displistmesh_to_mesh(DispListMesh *dlm, Mesh *me) 
+{
 	MFace *mfaces;
 	int i;
 	
-	if (dlm->totvert>65000) {
+	if (dlm->totvert>MESH_MAX_VERTS) {
 		error("Too many vertices");
 	} else {
 		me->totface= dlm->totface;
@@ -275,7 +284,7 @@ void displistmesh_to_mesh(DispListMesh *dlm, Mesh *me) {
 	
 		for (i=0; i<me->totface; i++) {
 			MFace *mf= &mfaces[i];
-			MFaceInt *oldmf= &dlm->mface[i];
+			MFace *oldmf= &dlm->mface[i];
 		
 			mf->v1= oldmf->v1;
 			mf->v2= oldmf->v2;
@@ -716,7 +725,7 @@ void addnormalsDispList(Object *ob, ListBase *lb)
 				dl->nors= MEM_mallocN(sizeof(*dl->nors)*3*dlm->totface, "meshnormals");
 				
 				for (i=0; i<dlm->totface; i++) {
-					MFaceInt *mf= &dlm->mface[i];
+					MFace *mf= &dlm->mface[i];
 					float *no= &dl->nors[i*3];
 					
 					if (mf->v3) {
@@ -904,7 +913,7 @@ void shadeDispList(Object *ob)
 					}		
 			
 					for (i=0; i<dlm->totface; i++) {
-						MFaceInt *mf= &dlm->mface[i];
+						MFace *mf= &dlm->mface[i];
 
 						if (mf->v3) {
 							int j, vidx[4], nverts= mf->v4?4:3;
@@ -1620,6 +1629,7 @@ void set_displist_onlyzero(int val)
 
 void makeDispList(Object *ob)
 {
+	EditMesh *em = G.editMesh;
 	Mesh *me;
 	Nurb *nu;
 	Curve *cu;
@@ -1643,15 +1653,14 @@ void makeDispList(Object *ob)
 		tex_space_mesh(ob->data);
 
 		object_deform(ob);	
-
+		
 		if(ob->effect.first) object_wave(ob);
 		
-		if (mesh_uses_displist(me)) {
+		if (mesh_uses_displist(me)) {  /* subsurf */
 			DispListMesh *dlm;
 
 			if (ob==G.obedit) {
-				dlm= subsurf_make_dispListMesh_from_editmesh(&G.edve, &G.eded, &G.edvl, 
-													me->subdiv, me->flag, me->subsurftype);
+				dlm= subsurf_make_dispListMesh_from_editmesh(em, me->subdiv, me->flag, me->subsurftype);
 			} else {
 				DispList *dlVerts= find_displist(&ob->disp, DL_VERTS);
 				dlm= subsurf_make_dispListMesh_from_mesh(me, dlVerts?dlVerts->verts:NULL, 
@@ -2206,16 +2215,17 @@ void test_all_displists(void)
 			ob= base->object;
 			
 
-			if(ob->type==OB_MBALL && ob->ipo) {
+			if(ob->type==OB_MBALL && (ob->ipo || ob->parent)) {
 				// find metaball object holding the displist
 				// WARNING: if more metaballs have IPO's the displist
-				// is recalculated to often...
+				// is recalculated to often... do we free the displist
+				// and rely on the drawobject.c to build it again when needed
 
 				if(ob->disp.first == NULL) {
 					ob= find_basis_mball(ob);
 				}
-
-				makeDispList(ob);
+				// makeDispList(ob);
+				freedisplist(&ob->disp);
 			}
 			else if(ob->parent) {
 
@@ -2230,6 +2240,8 @@ void test_all_displists(void)
 #endif
 			}
 
+			/* warn, ob pointer changed in case of OB_MALL */
+
 			if ELEM(ob->type, OB_CURVE, OB_SURF) {
 				if(ob!=G.obedit) {
 					if( ((Curve *)(ob->data))->key ) makeDispList(ob);
@@ -2247,7 +2259,7 @@ void test_all_displists(void)
 			else if(ob->type==OB_MESH) {
 				if(ob->effect.first) object_wave(ob);
 				if(ob!=G.obedit) {
-					if( ((Mesh *)(ob->data))->key ) makeDispList(ob);
+					if(( ((Mesh *)(ob->data))->key )||(ob->effect.first)) makeDispList(ob);
 				}
 			}
 
