@@ -1,5 +1,5 @@
 /**
- * $Id: BSE_drawnla.h,v 1.4 2002/12/27 13:10:20 mein Exp $
+ * $Id: BSE_drawnla.h,v 1.6 2004/04/22 12:36:26 ton Exp $
  *
  * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
  *
@@ -33,7 +33,10 @@
 #ifndef BSE_DRAWNLA_H
 #define BSE_DRAWNLA_H
 
-void drawnlaspace(void);
+struct ScrArea;
+
+void drawnlaspace(struct ScrArea *sa, void *spacedata);
+void do_nlabuts(unsigned short event);
 
 #endif /* BSE_DRAWNLA */
 
