@@ -42,6 +42,7 @@
 #endif
 
 #include "DNA_mesh_types.h"
+#include "DNA_meshdata_types.h"
 #include "DNA_key_types.h"
 #include "DNA_listBase.h"
 #include "DNA_object_types.h"
@@ -260,7 +261,7 @@ typedef struct {
 	float no[3];
 	float uvco[3];
 	int index;
-	char flag; /* see MVert flag in DNA_mesh_types */
+	char flag; /* see MVert flag in DNA_meshdata_types */
 
 } BPy_NMVert; /* an NMesh vertex */
 
