@@ -1,5 +1,5 @@
 /**
- * $Id: convertBlenderScene.c,v 1.54 2004/01/27 06:08:37 hos Exp $
+ * $Id: convertBlenderScene.c,v 1.64 2004/05/10 18:17:06 ton Exp $
  *
  * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
  *
@@ -64,6 +64,7 @@
 #include "DNA_object_types.h"
 #include "DNA_view3d_types.h"
 #include "DNA_mesh_types.h"
+#include "DNA_meshdata_types.h"
 #include "DNA_meta_types.h"
 #include "DNA_space_types.h"
 
@@ -339,7 +340,7 @@ static HaloRen *initstar(float *vec, float hasize)
 
 	RE_projectverto(vec, hoco);
 
-	if(	(R.r.mode & R_PANORAMA) ||  RE_testclip(hoco)==0 ) {
+	if(	(R.r.mode & R_PANORAMA) || (R.r.xparts*R.r.yparts>1) || RE_testclip(hoco)==0 ) {
 		har= RE_findOrAddHalo(R.tothalo++);
 	
 		/* projectvert is done in function zbufvlaggen again, because of parts */
@@ -1214,10 +1215,9 @@ static void init_render_mball(Object *ob)
 		VECCOPY(ver->co, data);
 		MTC_Mat4MulVecfl(mat, ver->co);
 
-		/* render normals are inverted in render */
-		xn= -nors[0];
-		yn= -nors[1];
-		zn= -nors[2];
+		xn= nors[0];
+		yn= nors[1];
+		zn= nors[2];
 
 		/* transpose ! */
 		ver->n[0]= imat[0][0]*xn+imat[0][1]*yn+imat[0][2]*zn;
@@ -1238,11 +1238,10 @@ static void init_render_mball(Object *ob)
 		vlr->v3= RE_findOrAddVert(startvert+index[2]);
 		vlr->v4= 0;
 
-		/* render normal are inverted */
 		vlr->len= CalcNormFloat(vlr->v1->co, vlr->v2->co, vlr->v3->co, vlr->n);
 
 		vlr->mat= ma;
-		vlr->puno= 0;
+		vlr->puno= 15; // no flip
 		vlr->flag= ME_SMOOTH+R_NOPUNOFLIP;
 		vlr->ec= 0;
 		vlr->lay= ob->lay;
@@ -1278,7 +1277,7 @@ static void init_render_mesh(Object *ob)
 	VlakRen *vlr, *vlr1;
 	VertRen *ver;
 	Material *ma;
-	MFaceInt *mfaceint = NULL;
+	MFace *mfaceint = NULL;
 	MSticky *ms;
 	PartEff *paf;
 	DispList *dl;
@@ -1501,8 +1500,11 @@ static void init_render_mesh(Object *ob)
 						v4= mfaceint->v4;
 						flag= mfaceint->flag;
 						puno= mfaceint->puno;
-						edcode= mfaceint->edcode;
-					} else {
+						/* if mfaceint, then dlm is not NULL too */
+						if(dlm->flag & ME_OPT_EDGES) edcode= mfaceint->edcode;
+						else edcode= ME_V1V2|ME_V2V3|ME_V3V4|ME_V4V1;
+					} 
+					else {
 						mat_nr= mface->mat_nr;
 						v1= mface->v1;
 						v2= mface->v2;
@@ -1759,7 +1761,7 @@ void RE_add_render_lamp(Object *ob, int doshadbuf)
 		lar->spottexfac= 1.0/(xn);
 
 		if(lar->mode & LA_ONLYSHADOW) {
-			if((lar->mode & LA_SHAD)==0) lar->mode -= LA_ONLYSHADOW;
+			if((lar->mode & (LA_SHAD|LA_SHAD_RAY))==0) lar->mode -= LA_ONLYSHADOW;
 		}
 
 	}
@@ -2528,6 +2530,7 @@ static void init_render_curve(Object *ob)
 			for(a=0; a<dl->parts; a++, index+=3) {
 
 				vlr= RE_findOrAddVlak(R.totvlak++);
+				vlr->ob = ob;	/* yafray: correction for curve rendering, obptr was not set */
 				vlr->v1= RE_findOrAddVert(startvert+index[0]);
 				vlr->v2= RE_findOrAddVert(startvert+index[1]);
 				vlr->v3= RE_findOrAddVert(startvert+index[2]);
@@ -2683,7 +2686,8 @@ void RE_freeRotateBlenderScene(void)
 				MEM_freeN(me->orco);
 				me->orco= 0;
 			}
-			if (mesh_uses_displist(me) && (me->subdiv!=me->subdivr)) {
+			if (mesh_uses_displist(me) && ((me->subdiv!=me->subdivr) || (ob->effect.first != NULL) ) ) { 
+			    /* Need to recalc for effects since they are time dependant */
 				makeDispList(ob);  /* XXX this should be replaced with proper caching */
 				me->subdivdone= 0;	/* needed to prevent multiple used meshes being recalculated */
 			}
@@ -2729,36 +2733,24 @@ static void check_non_flat_quads(void)
 			if(vlr->mat->mode & MA_WIRE);
 			else {
 				
-				/* blahj, render normals are inverted in render */
-				CalcNormFloat4(vlr->v4->co, vlr->v3->co, vlr->v2->co, vlr->v1->co, nor);
+				/* render normals are inverted in render! we calculate normal of single tria here */
+				CalcNormFloat(vlr->v4->co, vlr->v3->co, vlr->v1->co, nor);
 				
 				xn= nor[0]*vlr->n[0] + nor[1]*vlr->n[1] + nor[2]*vlr->n[2];
-				if( fabs(xn) < 0.990 ) {
+				if( fabs(xn) < 0.9990 ) {	// checked on noisy fractal grid
 				
 					if( xn<0.0 ) flipnorm= 1; else flipnorm= 0;
 					
-					/* recalc this nor, previous calc was with calcnormfloat4 */
-					if(flipnorm) {
-						if (vlr->flag & R_DIVIDE_24) CalcNormFloat(vlr->v1->co, vlr->v2->co, vlr->v4->co, vlr->n);
-						else CalcNormFloat(vlr->v1->co, vlr->v2->co, vlr->v3->co, vlr->n);
-					}
-					else {
-						if (vlr->flag & R_DIVIDE_24) CalcNormFloat(vlr->v4->co, vlr->v2->co, vlr->v1->co, vlr->n);
-						else CalcNormFloat(vlr->v3->co, vlr->v2->co, vlr->v1->co, vlr->n);
-					}
-					
 					vlr1= RE_findOrAddVlak(R.totvlak++);
 					*vlr1= *vlr;
 					vlr1->flag |= R_FACE_SPLIT;
-					
-					if(flipnorm) VecMulf(nor, -1.0);
-					VECCOPY(vlr1->n, nor);
 										
-					if (vlr->flag&R_DIVIDE_24) {
-						vlr1->v1=vlr->v2;
-						vlr1->v2=vlr->v3;
-						vlr1->v3=vlr->v4;
-						vlr->v3 =vlr->v4;
+					/* new vertex pointers */
+					if (vlr->flag & R_DIVIDE_24) {
+						vlr1->v1= vlr->v2;
+						vlr1->v2= vlr->v3;
+						vlr1->v3= vlr->v4;
+						vlr->v3 = vlr->v4;
 						
 						vlr1->flag |= R_DIVIDE_24;	
 					}
@@ -2769,8 +2761,18 @@ static void check_non_flat_quads(void)
 						
 						vlr1->flag &= ~R_DIVIDE_24;
 					}
+					vlr->v4 = vlr1->v4 = NULL;
+					
+					/* new normals */
+					if(flipnorm) {
+						CalcNormFloat(vlr->v1->co, vlr->v2->co, vlr->v3->co, vlr->n);
+						CalcNormFloat(vlr1->v1->co, vlr1->v2->co, vlr1->v3->co, vlr1->n);
+					}
+					else {
+						CalcNormFloat(vlr->v3->co, vlr->v2->co, vlr->v1->co, vlr->n);
+						CalcNormFloat(vlr1->v3->co, vlr1->v2->co, vlr1->v1->co, vlr1->n);
+					}
 					
-					vlr->v4 = vlr1->v4 = 0;
 				/* so later UV can be pulled from original tface, look for R_DIVIDE_24 for direction */
 					vlr1->tface=vlr->tface; 
 					
@@ -2814,6 +2816,9 @@ void RE_rotateBlenderScene(void)
 #ifdef __NLA
 	do_all_actions();
 	rebuild_all_armature_displists();
+	/* so nice, better do it twice */
+	do_all_actions();
+	rebuild_all_armature_displists();
 #endif
 	do_all_ikas();
 	test_all_displists();
@@ -2953,11 +2958,18 @@ void RE_rotateBlenderScene(void)
 					free_duplilist();
 				}
 				else {
-					/* yafray: if there are linked data objects (except lamps),
+					/* yafray: if there are linked data objects (except lamps or empties),
 					   yafray only needs to know about one, the rest can be instanciated.
 					   The dupliMtx list is used for this purpose */
 					if (R.r.renderer==R_YAFRAY) {
-						if ((ob->type!=OB_LAMP) && (YAF_objectKnownData(ob)))
+						/* Special case, parent object dupli's: ignore lattices */
+						if (ob->parent) {
+							if ((ob->parent->type!=OB_LATTICE) && (YAF_objectKnownData(ob)))
+								printf("From parent: Added dupli matrix for linked data object %s\n", ob->id.name);
+							else
+								init_render_object(ob);
+						}
+						else if ((ob->type!=OB_EMPTY) && (ob->type!=OB_LAMP) && (YAF_objectKnownData(ob)))
 							printf("Added dupli matrix for linked data object %s\n", ob->id.name);
 						else
 							init_render_object(ob);
