@@ -84,9 +84,9 @@ short bgpicmode=0, near=1000, far=1000;
 MTex emptytex;
 MTex mtexcopybuf;
 
-char texstr[15][8]= {"None"  , "Clouds" , "Wood", "Marble", "Magic"  , "Blend",
-					 "Stucci", "Noise"  , "Image", "Plugin", "EnvMap" , "",
-					 ""      , ""       , ""};
+char texstr[20][12]= {"None"  , "Clouds" , "Wood", "Marble", "Magic"  , "Blend",
+					 "Stucci", "Noise"  , "Image", "Plugin", "EnvMap" , "Musgrave",
+					 "Voronoi", "DistNoise", "", "", "", "", "", ""};
 /*  ---------------------------------------------------------------------- */
 
 void test_idbutton_cb(void *namev, void *arg2_unused)
@@ -315,6 +315,9 @@ void do_butspace(unsigned short event)
 	else if(event<=B_CONSTRAINTBUTS) {
 		do_constraintbuts(event);
 	}
+	else if(event<=B_UVAUTOCALCBUTS) {
+		do_uvautocalculationbuts(event);
+	}
 	else if(event==REDRAWVIEW3D) allqueue(event, 1);	// 1=do header too
 	else if(event>REDRAWVIEW3D) allqueue(event, 0);
 }
@@ -333,6 +336,9 @@ void butspace_context_switch(SpaceButs *buts, Base *new)
 			
 		}
 		else if(tab == TAB_SHADING_TEX) {
+			if(new->object->type==OB_LAMP) buts->texfrom= 2;
+			else if(new->object->type==OB_CAMERA) buts->texfrom= 1;
+			else buts->texfrom= 0;
 		}
 		else if(tab == TAB_SHADING_RAD) {
 		}
@@ -444,9 +450,6 @@ void drawbutspace(ScrArea *sa, void *spacedata)
 
 	uiClearButLock();
 
-	/* since panels give different layouts, we have to make sure v2d.tot matches */
-	uiMatchPanel_view2d(sa);
-
 	/* when align changes, also do this for new panels */
 	/* don't always align, this function is called during AnmatePanels too */
 	if(sbuts->align)
@@ -455,6 +458,9 @@ void drawbutspace(ScrArea *sa, void *spacedata)
 
 	uiDrawBlocksPanels(sa, align);	
 	
+	/* since panels give different layouts, we have to make sure v2d.tot matches */
+	uiMatchPanel_view2d(sa);
+
 	sbuts->re_align= 0;
 	// also for memory for finding which texture you'd like to see
 	sbuts->mainbo= sbuts->mainb;
