@@ -130,7 +130,8 @@
 
 #include "butspace.h" // own module
 
-float hspeed=0.1, prspeed=0.0, prlen=0.0;
+static float prspeed=0.0;
+float prlen=0.0;
 
 
 
@@ -931,13 +932,13 @@ extern ListBase editNurb;
 
 void do_common_editbuts(unsigned short event) // old name, is a mix of object and editing events.... 
 {
+	EditMesh *em = G.editMesh;
 	EditVlak *evl;
 	Base *base;
 	Object *ob;
 	Mesh *me;
 	Nurb *nu;
 	Curve *cu;
-	MFace *mface;
 	BezTriple *bezt;
 	BPoint *bp;
 	unsigned int local;
@@ -948,7 +949,7 @@ void do_common_editbuts(unsigned short event) // old name, is a mix of object an
 	case B_MATWICH:
 		if(G.obedit && G.obedit->actcol>0) {
 			if(G.obedit->type == OB_MESH) {
-				evl= G.edvl.first;
+				evl= em->faces.first;
 				while(evl) {
 					if( vlakselectedAND(evl, 1) ) {
 						if(index== -1) index= evl->mat_nr;
@@ -993,7 +994,7 @@ void do_common_editbuts(unsigned short event) // old name, is a mix of object an
 		if(G.obedit && G.obedit->actcol>0) {
 			if(G.obedit->type == OB_MESH) {
 				undo_push_mesh("Assign material index");
-				evl= G.edvl.first;
+				evl= em->faces.first;
 				while(evl) {
 					if( vlakselectedAND(evl, 1) )
 						evl->mat_nr= G.obedit->actcol-1;
@@ -1016,23 +1017,10 @@ void do_common_editbuts(unsigned short event) // old name, is a mix of object an
 	case B_MATDESEL:
 		if(G.obedit) {
 			if(G.obedit->type == OB_MESH) {
-				evl= G.edvl.first;
-				while(evl) {
-					if(evl->mat_nr== G.obedit->actcol-1) {
-						if(event==B_MATSEL) {
-							if(evl->v1->h==0) evl->v1->f |= 1;
-							if(evl->v2->h==0) evl->v2->f |= 1;
-							if(evl->v3->h==0) evl->v3->f |= 1;
-							if(evl->v4 && evl->v4->h==0) evl->v4->f |= 1;
-						}
-						else {
-							if(evl->v1->h==0) evl->v1->f &= ~1;
-							if(evl->v2->h==0) evl->v2->f &= ~1;
-							if(evl->v3->h==0) evl->v3->f &= ~1;
-							if(evl->v4 && evl->v4->h==0) evl->v4->f &= ~1;
-						}
-					}
-					evl= evl->next;
+				if (event==B_MATSEL) {
+					editmesh_select_by_material(G.obedit->actcol-1);
+				} else {
+					editmesh_deselect_by_material(G.obedit->actcol-1);
 				}
 				allqueue(REDRAWVIEW3D, 0);
 			}
@@ -1118,7 +1106,7 @@ void do_common_editbuts(unsigned short event) // old name, is a mix of object an
 	case B_SETSOLID:
 		if(G.obedit) {
 			if(G.obedit->type == OB_MESH) {
-				evl= G.edvl.first;
+				evl= em->faces.first;
 				if (event == B_SETSMOOTH) undo_push_mesh("Set Smooth");
 				else if (event==B_SETSOLID) undo_push_mesh("Set Solid");
 				while(evl) {
@@ -1150,12 +1138,7 @@ void do_common_editbuts(unsigned short event) // old name, is a mix of object an
 				if(TESTBASELIB(base)) {
 					if(base->object->type==OB_MESH) {
 						me= base->object->data;
-						mface= me->mface;
-						for(a=0; a<me->totface; a++, mface++) {
-							if(event==B_SETSMOOTH) mface->flag |= ME_SMOOTH;
-							else mface->flag &= ~ME_SMOOTH;
-						}
-
+						mesh_set_smooth_flag(me, (event==B_SETSMOOTH));
 						makeDispList(base->object);
 					}
 					else if ELEM(base->object->type, OB_SURF, OB_CURVE) {
@@ -1197,7 +1180,6 @@ void do_common_editbuts(unsigned short event) // old name, is a mix of object an
 
 void object_panel_draw(Object *ob)
 {
-	ID *id;
 	uiBlock *block;
 	int xco, a, dx, dy;
 	
@@ -1224,16 +1206,13 @@ void object_panel_draw(Object *ob)
 
 	uiBlockEndAlign(block);
 
-	id= ob->data;
-	if(id && id->lib) uiSetButLock(1, "Can't edit library data");
-
 	uiDefBut(block, LABEL, 0, "Drawtype",						28,200,100,18, 0, 0, 0, 0, 0, "");
 	uiDefButC(block, MENU, REDRAWVIEW3D, "Drawtype%t|Bounds %x1|Wire %x2|Solid %x3|Shaded %x4",	
 																28,180,100,18, &ob->dt, 0, 0, 0, 0, "Sets the drawing type of the active object");
 	uiDefBut(block, LABEL, 0, "Draw Extra",						28,160,100,18, 0, 0, 0, 0, 0, "");
 	uiBlockBeginAlign(block);
 	uiDefButC(block, TOG|BIT|0, REDRAWVIEW3D, "Bounds",		28, 140, 100, 18, &ob->dtx, 0, 0, 0, 0, "Displays the active object's bounds");
-	uiDefButS(block, MENU, REDRAWVIEW3D, "Boundary Display%t|Box%x0|Sphere%x1|Cylinder%x2|Cone%x3|Polyheder",
+	uiDefButS(block, MENU, REDRAWVIEW3D, "Boundary Display%t|Box%x0|Sphere%x1|Cylinder%x2|Cone%x3|Polyheder%x4",
 															28, 120, 100, 18, &ob->boundtype, 0, 0, 0, 0, "Selects the boundary display type");
 	uiDefButBitC(block, TOG, OB_DRAWWIRE, REDRAWVIEW3D, "Wire",		28, 100, 100, 18, &ob->dtx, 0, 0, 0, 0, "Displays the active object's wireframe in shaded drawing modes");
 	uiDefButBitC(block, TOG, OB_AXIS, REDRAWVIEW3D, "Axis",		28, 80, 100, 18, &ob->dtx, 0, 0, 0, 0, "Displays the active object's centre and axis");
@@ -1622,10 +1601,14 @@ void object_panels()
 	/* check context here */
 	ob= OBACT;
 	if(ob) {
+		if(ob->id.lib) uiSetButLock(1, "Can't edit library data");
+
 		object_panel_anim(ob);
 		object_panel_draw(ob);
 		object_panel_constraint();
 		if(ob->type==OB_MESH) object_panel_effects(ob);
+		
+		uiClearButLock();
 	}
 }
 
