@@ -1,5 +1,5 @@
 /**
- * $Id: editkey.c,v 1.10 2004/01/13 14:50:43 phase Exp $
+ * $Id: editkey.c,v 1.12 2004/04/20 18:27:09 ton Exp $
  *
  * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
  *
@@ -51,6 +51,7 @@
 #include "DNA_ipo_types.h"
 #include "DNA_key_types.h"
 #include "DNA_mesh_types.h"
+#include "DNA_meshdata_types.h"
 #include "DNA_object_types.h"
 #include "DNA_screen_types.h"
 #include "DNA_space_types.h"
@@ -277,6 +278,9 @@ void make_rvk_slider(uiBlock *block, Key *key, int keynum,
 				  meshslidervals+keynum, min, max, 10, 2,
 				  "Slider to control rvk");
 	uiButSetFunc(but, rvk_slider_func, key, keynums+keynum);
+	// no hilite, the winmatrix is not correct later on...
+	uiButSetFlag(but, UI_NO_HILITE);
+
 }
 
 static void default_key_ipo(Key *key)
