@@ -1,5 +1,5 @@
 /**
- * $Id: usiblender.c,v 1.46 2004/01/29 20:30:05 aphex Exp $
+ * $Id: usiblender.c,v 1.54 2004/05/04 21:16:39 zuster Exp $
  *
  * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
  *
@@ -65,7 +65,7 @@
 #include "DNA_object_types.h"
 #include "DNA_space_types.h"
 #include "DNA_userdef_types.h"
-#include "DNA_mesh_types.h"
+#include "DNA_sound_types.h"
 
 #include "BKE_blender.h"
 #include "BKE_curve.h"
@@ -126,6 +126,7 @@ void BIF_read_file(char *name)
 {
 	extern short winqueue_break; /* editscreen.c */
 
+
 	//here?
 	//sound_end_all_sounds();
 
@@ -172,6 +173,8 @@ int BIF_read_homefile(void)
 	BIF_InitTheme();	// sets default again
 
 	if (success) {
+		mainwindow_set_filename_to_title(tstr);
+
 		G.save_over = 0;
 
 		/*  disable autoplay in .B.blend... */
@@ -220,18 +223,21 @@ int BIF_read_homefile(void)
 			U.vrmlflag= USER_VRML_LAYERS;
 		}
 
-#ifndef __sgi
-		/* startup 2.26 with aa fonts ! */
-		if (G.main->versionfile <= 225) {
-			U.transopts |= USER_DOTRANSLATE;
-		}
-#endif
-
 		space_set_commmandline_options();
 
 		if (U.undosteps==0) U.undosteps=32;
 
 		reset_autosave();
+
+#ifdef INTERNATIONAL
+		read_languagefile();
+	
+		if(U.transopts & USER_DOTRANSLATE)
+			start_interface_font();
+		else
+			G.ui_international = FALSE;
+#endif // INTERNATIONAL
+
 	}
 
 	return success;
@@ -415,23 +421,9 @@ void BIF_write_homefile(void)
 	char *err, tstr[FILE_MAXDIR+FILE_MAXFILE];
 	int write_flags;
 	
-	/* "change-over" period for Windows - Ctrl+U now saves in ~/.blender,
-	   but blender still checks the old locations.
-	   To be removed at v2.4 or so! ;)
-	*/
-
-#if 0
-	char dir[FILE_MAXDIR+FILE_MAXFILE];
-	BLI_getInstallationDir(dir);
-
-	strcat(dir,"/.blender/");
-
-	BLI_make_file_string("/", tstr, dir, ".B.blend");
-#else
 	BLI_make_file_string("/", tstr, BLI_gethome(), ".B.blend");
-#endif
 		
-		/*  force save as regular blend file */
+	/*  force save as regular blend file */
 	write_flags = G.fileflags & ~(G_FILE_COMPRESS | G_FILE_LOCK | G_FILE_SIGN);
 	BLO_write_file(tstr, write_flags, &err);
 }
@@ -487,27 +479,29 @@ static void initbuttons(void)
 	clear_matcopybuf();
 }
 
+
+static void sound_init_listener(void)
+{
+	G.listener = MEM_callocN(sizeof(bSoundListener), "soundlistener");
+	G.listener->gain = 1.0;
+	G.listener->dopplerfactor = 1.0;
+	G.listener->dopplervelocity = 1.0;
+}
+
 void BIF_init(void)
 {
 
 	initscreen();	/* for (visuele) speed, this first, then setscreen */
 	initbuttons();
 	InitCursorData();
-
+	sound_init_listener();
+	
 	init_draw_rects();	/* drawobject.c */
 	BIF_read_homefile();
 	init_gl_stuff();	/* drawview.c, after homefile */
 	readBlog();
 	strcpy(G.lib, G.sce);
 
-#ifdef INTERNATIONAL
-	read_languagefile();
-
-	if(U.transopts & USER_DOTRANSLATE)
-		start_interface_font();
-	else
-		G.ui_international = FALSE;
-#endif // INTERNATIONAL
 }
 
 /***/
@@ -556,6 +550,7 @@ void exit_usiblender(void)
 	free_txt_data();
 
 	sound_exit_audio();
+	if(G.listener) MEM_freeN(G.listener);
 
 #ifdef WITH_QUICKTIME
 	quicktime_exit();
@@ -587,9 +582,11 @@ void exit_usiblender(void)
 	printf("\nBlender quit\n");
 
 #ifdef WIN32   
-	// when debugging enter infinite loop to enable   
-	// reading the printouts...   
-	while(G.f & G_DEBUG) {PIL_sleep_ms(10);}   
+	/* ask user to press enter when in debug mode */
+	if(G.f & G_DEBUG) {
+		printf("press enter key to exit...\n\n");
+		getchar();
+	}
 #endif 
 
 
