@@ -1,7 +1,7 @@
 /**
  * Cast a ray and feel for objects
  *
- * $Id: KX_RaySensor.h,v 1.5 2002/12/27 13:10:48 mein Exp $
+ * $Id: KX_RaySensor.h,v 1.6 2004/03/22 22:01:52 jesterking Exp $
  *
  * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
  *
@@ -44,7 +44,7 @@ class KX_RaySensor : public SCA_ISensor
 	STR_String		m_propertyname;
 	bool			m_bFindMaterial;
 	double			m_distance;
-	class KX_Scene* m_ketsjiScene;
+	class KX_Scene* m_scene;
 	bool			m_bTriggered;
 	int				m_axis;
 	bool			m_rayHit;
