@@ -1,5 +1,5 @@
 /**
- * $Id: RAS_IPolygonMaterial.h,v 1.5 2002/12/27 13:10:56 mein Exp $
+ * $Id: RAS_IPolygonMaterial.h,v 1.7 2004/05/04 09:34:02 kester Exp $
  *
  * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
  *
@@ -43,17 +43,20 @@
 
 class RAS_IRasterizer;
 
+/**
+ * Material properties.
+ */
 class RAS_IPolyMaterial
 {
 	//todo: remove these variables from this interface/protocol class
 protected:
-	STR_HashedString    m_texturename;
-	STR_String          m_materialname; //also needed for touchsensor  
-	int					m_tile;
-	int					m_tilexrep,m_tileyrep;
-	int					m_drawingmode;	// tface->mode
-	int					m_transparant;
-	int					m_lightlayer;
+	STR_HashedString		m_texturename;
+	STR_HashedString		m_materialname; //also needed for touchsensor  
+	int				m_tile;
+	int				m_tilexrep,m_tileyrep;
+	int				m_drawingmode;	// tface->mode
+	int				m_transparant;
+	int				m_lightlayer;
 	bool				m_bIsTriangle;
 	
 public:
@@ -104,6 +107,7 @@ public:
 	virtual void Activate(RAS_IRasterizer* rasty, TCachingInfo& cachingInfo) const {}
 
 	bool				Equals(const RAS_IPolyMaterial& lhs) const;
+	bool				Less(const RAS_IPolyMaterial& rhs) const;
 	int					GetLightLayer();
 	bool				IsTransparant();
 	bool				UsesTriangles();
@@ -118,5 +122,10 @@ inline  bool operator ==( const RAS_IPolyMaterial & rhs,const RAS_IPolyMaterial
 	return ( rhs.Equals(lhs));
 }
 
+inline  bool operator < ( const RAS_IPolyMaterial & lhs, const RAS_IPolyMaterial & rhs)
+{
+	return lhs.Less(rhs);
+}
+
 #endif //__RAS_IPOLYGONMATERIAL
 
