@@ -1,5 +1,5 @@
 /**
- * $Id: RAS_MaterialBucket.h,v 1.5 2002/12/27 13:10:56 mein Exp $
+ * $Id: RAS_MaterialBucket.h,v 1.7 2004/05/04 09:34:02 kester Exp $
  *
  * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
  *
@@ -51,7 +51,9 @@ typedef vector< KX_IndexArray* > vecIndexArrays;
 typedef vector<RAS_TexVert> KX_VertexArray;
 
 
-
+/**
+ * KX_VertexIndex
+ */
 struct KX_VertexIndex {
 public:
 	KX_VertexIndex(int size);
@@ -62,7 +64,9 @@ public:
 };
 
 
-
+/**
+ * KX_MeshSlot.
+ */
 class KX_MeshSlot
 {
 public:
@@ -74,7 +78,7 @@ public:
 	mutable bool  		    m_bObjectColor;
 	mutable MT_Vector4		m_RGBAcolor;
 	
-	KX_MeshSlot() :m_bVisible(true), m_pDeformer(NULL) {}
+	KX_MeshSlot() :m_pDeformer(NULL), m_bVisible(true) {}
 	//	KX_MeshSlot() :m_bVisible(true) {}
 	
 	bool					Less(const KX_MeshSlot& lhs) const;
@@ -86,7 +90,9 @@ inline bool operator <( const KX_MeshSlot& rhs,const KX_MeshSlot& lhs)
 	return ( rhs.Less(lhs));
 }
 
-
+/**
+ * Contains a list of meshs with the same material properties.
+ */
 class RAS_MaterialBucket
 {
 	typedef std::set<KX_MeshSlot> T_MeshSlotList;
@@ -108,8 +114,8 @@ public:
 	void	SchedulePolygons(int drawingmode);
 	void	ClearScheduledPolygons();
 	
-	RAS_IPolyMaterial*		GetPolyMaterial();
-	bool	IsTransparant();
+	RAS_IPolyMaterial*		GetPolyMaterial() const;
+	bool	IsTransparant() const;
 		
 	static void	StartFrame();
 	static void EndFrame();
@@ -120,6 +126,16 @@ public:
 								bool visible,
 								bool color,
 								const MT_Vector4& rgbavec);
+	
+	struct less
+	{
+		bool operator()(const RAS_MaterialBucket* x, const RAS_MaterialBucket* y) const 
+		{ 
+			return *x->GetPolyMaterial() < *y->GetPolyMaterial(); 
+		}
+	};
+	
+	typedef set<RAS_MaterialBucket*, less> Set;
 };
 
 #endif //__KX_BUCKET
